from setuptools import setup

setup(name='jdistributions',
      version='0.1',
      description='Data Distribution - Gaussian and Binomial',
      packages=['jdistributions'],
      author = 'Jish N',
      zip_safe=False)
